@@ -1,6 +1,5 @@
 #' @include TriangleModel.R
 #' 
-
 ProjectToDev = function(objTriangleModel, lOriginYears, MaxDev)
 {
   objTriangle = objTriangleModel@Triangle
@@ -18,7 +17,7 @@ ProjectToDev = function(objTriangleModel, lOriginYears, MaxDev)
   
   df = do.call("rbind", mojo)
   
-  df$DevelopmentLag = as.period(new_interval(df$OriginPeriodStart, df$EvaluationDate + days(1)))
+  df$DevelopmentLag = as.period(interval(df$OriginPeriodStart, df$EvaluationDate + days(1)))
   df$DevInteger = round(df$DevelopmentLag / DevelopmentInterval, 0)
   
   priors = GetPriorNames(objTriangle@StochasticMeasures)
